# encoding: utf-8
#
# Cookbook Name:: mu
# Recipe:: default
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe 'apt'

case node['mu']['emacs_package']
when false
  package node['mu']['emacs_package'] do
    action :install
  end
end

node['mu']['packages'].each do |pkg|
  package pkg do
    action :upgrade
  end
end

remotefile = 'http://mu0.googlecode.com/files/mu-'
remotefile << node['mu']['version'] << '.tar.gz'
localfile = Chef::Config[:file_cache_path] + '/mu.tar.gz'

remote_file localfile do
  source remotefile
  mode '0644'
end

directory node['mu']['build_dir'] do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
  recursive true
end

execute 'untar' do
  cwd node['mu']['build_dir']
  command 'tar --strip-components 1 -xzf ' + localfile
end

execute 'configure and make' do
  cwd node['mu']['build_dir']
  command './configure && make'
end

execute 'Install mu' do
  cwd node['mu']['build_dir']
  command 'sudo make install'
end
